# Contributing

Anyone can contribute to EpyNN development.

The **epynn** module contains:

* Layers and commons exhaustively described at [epynn.net](epynn.net).
* Required sources for API base functioning.

The **dpynn** module contains:

* Other layers and commons.
* Base API development.

New layers should be implemented in **dpynn** module.

Practical examples should be implemented in **nnlive** module.
